
.. automodule:: bci_framework
   :members:
   :no-undoc-members:
   :no-show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bci_framework.default_extensions
   bci_framework.extensions
   bci_framework.framework
   bci_framework.kafka_scripts
   bci_framework.utils
